contexttools.get_clef_marks_attached_to_component
=================================================

.. autofunction:: abjad.tools.contexttools.get_clef_marks_attached_to_component.get_clef_marks_attached_to_component
   :noindex:
